<?xml version="1.0" encoding="utf-8" standalone="no"?>
<xsl:stylesheet version="0.1" xmlns:prd="Prometheus" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html"/>
<xsl:template match="/">
	<html>
	<head>
	<title>Prometheus Reference</title>
	<style>
		h1 {font-size:16pt; text-decoration:underline;}
		h2 {font-size:14pt; text-deocration:underline; font-variant:small caps;}
		h3 {font-size:12pt; font-weight:bold;)
		h4 (font-size:12pt; font-style:italic;)
		p {font-size:12pt; margin:0; text-indent:2em;}
		p.spellblock {text-indent:0;}
		li,td {font-size:12pt;}
	</style>
	</head>
	<body>
		<xsl:apply-templates/>
	</body>
	</html>
</xsl:template>

<!-- Chapter, Rule, SubRule -->

<xsl:template match="//ChapterName">
<h1><xsl:apply-templates/></h1></xsl:template>

<xsl:template match="//SectionName">
	<h2><xsl:apply-templates/></h2>
</xsl:template>

<xsl:template match="//RuleName">
	<h3><xsl:apply-templates/></h3>
</xsl:template>

<xsl:template match="//SubRuleName">
	<h3><xsl:apply-templates/></h3>
</xsl:template>

<xsl:template match="//P">
  <p><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="//List">
	<ol><xsl:apply-templates/></ol>
</xsl:template>

<xsl:template match="//ListItem">
  <LI><xsl:apply-templates /></LI>
</xsl:template>

<xsl:template match="//Em">
  <I><xsl:apply-templates /></I>
</xsl:template>

<xsl:template match="//Strong">
  <b><xsl:apply-templates /></b>
</xsl:template>


<xsl:template match="//text()">
   <xsl:value-of select="."/>
</xsl:template>


<!-- Race -->

<xsl:template match="//RaceName">
	<h3><xsl:apply-templates/></h3>
</xsl:template>

<xsl:template match="//RaceIntro">
	<p><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="//Personality">
	<p><b>Personality: </b><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="//Physical_Description">
	<p><b>Physical Description: </b><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="//Random_Height_and_Weight">
	<p><b>Random Height and Weight: </b><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="//Random_Starting_Age">
	<p><b>Random Starting Age: </b><xsl:apply-templates/></p>
</xsl:template>

<xsl:template match="//Age_Catagories">
	<p><b>Age Catagories: </b>
		Maturity at <xsl:value-of select="Maturity"/>, 
		Middle Age at <xsl:value-of select="MiddleAge"/>, 
		Old Age at <xsl:value-of select="OldAge"/>, 
		Venerable at <xsl:value-of select="Venerable"/>, 
		Maximum Age: <xsl:value-of select="MaxAge"/>
	</p>
</xsl:template>

<xsl:template match="//RacialAbilities">
	<p><b>Racial Abilities</b></p>
	<ul><xsl:apply-templates/></ul>
</xsl:template>

<!-- Class -->

<xsl:template match="//ClassDesc">
	<h2><xsl:value-of select="ClassName"/></h2>
	<xsl:apply-templates select="Roleplaying"/>
	<xsl:apply-templates select="ClassTable"/>
	<xsl:apply-templates select="Roleplaying"/>
</xsl:template>

<xsl:template match="//RolePlaying">
	<h3>Roleplaying Information</h3>
	<xsl:if test="ClassIntro"><p><xsl:value-of select="ClassIntro"/></p></xsl:if>
	<xsl:if test="Adventures"><p><b>Adventures: </b><xsl:value-of select="Adventures"/></p></xsl:if>
	<xsl:if test="Alignment"><p><b>Alignment: </b><xsl:value-of select="Alignment"/></p></xsl:if>
	<xsl:if test="Religion"><p><b>Religion: </b><xsl:value-of select="Religion"/></p></xsl:if>
	<xsl:if test="Background"><p><b>Background: </b><xsl:value-of select="Background"/></p></xsl:if>
	<xsl:if test="Races"><p><b>Races: </b><xsl:value-of select="Races"/></p></xsl:if>
	<xsl:if test="Other_Classes"><p><b>Other Classes: </b><xsl:value-of select="Other_Classes"/></p></xsl:if>
</xsl:template>

<xsl:template match="//ClassTable">
	<table>
	<tr><th>Class Facet</th><th>Value</th></tr>
	<tr><td>Max Level</td><td><xsl:value-of select="MaxLvl"/></td></tr>
	<tr><td>AttackRate</td><td><xsl:value-of select="AttackRate"/></td></tr>
	<tr><td>FortSave</td><td><xsl:value-of select="FortSave"/></td></tr>
	<tr><td>RefSave</td><td><xsl:value-of select="RefSave"/></td></tr>
	<tr><td>WillSave</td><td><xsl:value-of select="WillSave"/></td></tr>
	<tr><td>Defense</td><td><xsl:value-of select="Defense"/></td></tr>
	<tr><td>SpellCasting</td><td><xsl:value-of select="SpellCasting"/></td></tr>
	</table>
</xsl:template>

<xsl:template match="//ClassAbilities">
	<xsl:if test="Abilities"><p><b>Abilities: </b><xsl:value-of select="Abilities"/></p></xsl:if>
	<xsl:if test="Prerequisites"><p><b>Prerequisites: </b></p><xsl:apply-templates/></xsl:if>
	<p><b>Hit Die: </b><xsl:value-of select="Hit_Die"/></p>
	<p>
		<b>Class Skills: </b>
		<xsl:for-each select="Class_Skills">
			<xsl:value-of select="SkillName"/> (<xsl:value-of select="ABscore"/>), 
		</xsl:for-each>
	</p>
	<p><b>Skill Points at Each Level: </b><xsl:value-of select="Skill_Points"/></p>
	<p><b>Weapon and Armor Proficiency: </b><xsl:value-of select="Proficiency"/></p>
	<xsl:for-each select="ClassAbility">
		<p>
			<b><xsl:value-of select="ClassAbName"/>: </b>
			<xsl:apply-templates select="Desc"/>
		</p>
		<xsl:apply-templates/>
	</xsl:for-each>
</xsl:template>

<!-- Skill -->

<!-- Feat -->

<!-- Item -->

<!-- Spell -->

<xsl:template match="//Spell">
	<h3><xsl:value-of select="Name"/></h3>
	<p><i><xsl:value-of select="ShortDesc"/></i></p>
	<p class="spellblock">
		<xsl:value-of select="School"/>
		<xsl:apply-templates select="subschool"/>
		<xsl:apply-templates select="Subtypes"/>
	</p>
		<xsl:apply-templates select="Circle"/>
		<xsl:apply-templates select="Mana"/>
		<xsl:apply-templates select="Components"/>
		<xsl:apply-templates select="Casting_Time"/>
		<xsl:apply-templates select="Range"/>
		<xsl:apply-templates select="T_A_E"/>
		<xsl:apply-templates select="Saving_Throw"/>
		<xsl:apply-templates select="Spell_Resistance"/>
	<hr/>
	<xsl:apply-templates select="Description"/>
</xsl:template>


<xsl:template match="//Description">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="//subschool">
	<xsl:text> (</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>) </xsl:text>
</xsl:template>

<xsl:template match="//SubTypes">
	<xsl:text> [</xsl:text>
	<xsl:apply-templates/>
	<xsl:text>] </xsl:text>
</xsl:template>

<xsl:template match="//SpellLevel">
	<p class="spellblock"><b>Level:</b> <xsl:apply-templates /></p>
</xsl:template>

<xsl:template match="//Mana">
	<p class="spellblock"><b>Mana:</b> <xsl:apply-templates /></p>
</xsl:template>

<xsl:template match="//Components">
	<p class="spellblock">
		<b>Components:</b> 
		<xsl:if test="V">V</xsl:if>
		<xsl:if test="S">S</xsl:if>
		<xsl:if test="M">M</xsl:if>	
		<xsl:if test="F">F</xsl:if>
		<xsl:if test="XP">XP</xsl:if>
	</p>
</xsl:template>

<xsl:template match="//Casting_Time">
	<p class="spellblock"><b>Casting Time:</b> <xsl:apply-templates /></p>
</xsl:template>

<xsl:template match="//Range">
	<p class="spellblock"><b>Range:</b> <xsl:apply-templates /></p>
</xsl:template>
	
<xsl:template match="//T_A_E">
	<p class="spellblock">
		<b><xsl:value-of select="./Type"/>: </b>
		<xsl:value-of select="./Text"/>
	</p>
</xsl:template>

<xsl:template match="//Saving_Throw">
	<p class="spellblock"><b>Saving Throw:</b> <xsl:apply-templates /></p>
</xsl:template>
	
<xsl:template match="//Spell_Resistance">
	<p class="spellblock"><b>Spell Resistance:</b> <xsl:apply-templates /></p>
</xsl:template>

<!-- Basic Text Formats -->

<xsl:template match="//Table">
	<p><b><xsl:value-of select="TableTitle"/></b></p>
	<table>
		<xsl:apply-templates/>	
	</table>
</xsl:template>

<xsl:template match="//TableRow">
	<tr>
		<xsl:apply-templates/>	
	</tr>
</xsl:template>

<xsl:template match="//TableCell">
	<td>
		<xsl:apply-templates/>	
	</td>
</xsl:template>


</xsl:stylesheet>